#
# spec file for package HepMC
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with rootio
%bcond_without pythia

Name:           HepMC
%define lname	libHepMC3-1
Version:        3.2.2
Release:        lp152.2.3.1
Summary:        An event record for High Energy Physics Monte Carlo Generators in C++
# Python bindings are BSD-3-Clause, packaged separately
License:        GPL-3.0-or-later
Group:          Development/Libraries/C and C++
URL:            http://hepmc.web.cern.ch/hepmc/
Source:         http://hepmc.web.cern.ch/hepmc/releases/%{name}3-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gcc-fortran
BuildRequires:  ghostscript-fonts-std
BuildRequires:  graphviz-gd
%if %{with pythia}
BuildRequires:  pythia-devel
%endif
BuildRequires:  python3
BuildRequires:  python3-devel
BuildRequires:  pkgconfig(zlib)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The HepMC package is an object oriented event record written in C++
for High Energy Physics Monte Carlo Generators. Many extensions from
HEPEVT, the Fortran HEP standard, are supported.

%package -n %{lname}
Summary:        An event record for High Energy Physics Monte Carlo Generators
License:        GPL-3.0-or-later
Group:          System/Libraries

%description -n %{lname}
The HepMC package is an object oriented event record written in C++
for High Energy Physics Monte Carlo Generators. Many extensions from
HEPEVT, the Fortran HEP standard, are supported: the number of entries
is unlimited, spin density matrices can be stored with each vertex,
flow patterns (such as color) can be stored and traced, integers
representing random number generator states can be stored, and an
arbitrary number of event weights can be included. Particles and
vertices are kept separate in a graph structure, physically similar to
a physics event. The added information supports the modularisation of
event generators. Event information is accessed by means of iterators
supplied with the package.

%package devel
Summary:        Header files for HepMC
License:        GPL-3.0-or-later
Group:          Development/Libraries/C and C++
Requires:       %{lname} = %{version}
Recommends:     %{name}-doc = %{version}

%description devel
The HepMC package is an object oriented event record written in C++
for High Energy Physics Monte Carlo Generators. Many extensions from
HEPEVT, the Fortran HEP standard, are supported.

This package provides the source and header files required for
developing with HepMC.

%package doc
Summary:        API documentation for HepMC
License:        GPL-3.0-or-later
Group:          Development/Libraries/C and C++

%description doc
This package provides the API documentation for the HepMC library.

%package -n python3-HepMC
Summary:        Python bindings for HepMC
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
Requires:       python3

%description -n python3-HepMC
The HepMC package is an object oriented event record written in C++
for High Energy Physics Monte Carlo Generators. Many extensions from
HEPEVT, the Fortran HEP standard, are supported.

This package provides the python module for coding with HepMC.

%prep
%autosetup -p1 -n %{name}3-%{version}

%build
%cmake -DHEPMC3_ENABLE_ROOTIO:BOOL=%{?with_rootio:ON}%{!?with_rootio:OFF} \
       -DHEPMC3_BUILD_DOCS:BOOL=ON \
       -DCMAKE_INSTALL_DOCDIR:PATH=%{_docdir}/%{name} \
       -DHEPMC3_BUILD_STATIC_LIBS:BOOL=OFF \
       -DHEPMC3_PYTHON_VERSIONS:STRING="%{py3_ver}" \
       -DCMAKE_SKIP_INSTALL_RPATH:BOOL=ON \
       -DHEPMC3_BUILD_EXAMPLES:BOOL=ON

%cmake_build

%install
%cmake_install

%fdupes %{buildroot}%{_docdir}/%{name}/

%post   -n %{lname} -p /sbin/ldconfig
%postun -n %{lname} -p /sbin/ldconfig

%files -n %{lname}
%{_libdir}/libHepMC3.so.*
%{_libdir}/libHepMC3search.so.*

%files devel
%license LICENCE COPYING
%doc README* ChangeLog DESIGN
%{_bindir}/HepMC3-config
%{_libdir}/libHepMC3.so
%{_libdir}/libHepMC3search.so
%{_includedir}/%{name}3/
%{_datadir}/%{name}3/

%files doc
%doc %{_docdir}/%{name}/

%files -n python3-HepMC
%license python/include/LICENSE
%{python3_sitearch}/pyHepMC3/
%{python3_sitearch}/pyHepMC3-%{version}-py%{py3_ver}.egg-info
%{python3_sitearch}/pyHepMC3.search-%{version}-py%{py3_ver}.egg-info

%changelog
* Tue Jul 14 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.2.2:
  * Fixed treatment of the weights in case of different number of
    weights and weight names.
  * Fixed WriterAsciiHepMC2 option for separate flows.
  * Improved treatment of python installation.
  * Split the sources of python bindings into smaller files to
    optimize compilation.
  * Improved cmake configuration for special cases, e.g. old
    cmake, no ROOT, some compilers, etc. Added more error
    handling.
  * Fixed compilation of the search module with Clang.
  * Added an example for search module.
  * Fixed the HepMC2 output for events without weights.
  * Fixed the signal vertex ID for HepMC2 output.
  * Added an interface for HepMC2 (in-memory-conversion).
  * Added functions to search module: search for relatives
    (particle or vertex)->(particle or vertex) in different
    combinations.
  * The previous point bumps .so version of the libHepMC3search to
    4.
  * Improved the configuration of Pythia8 for tests (minimal
    version requirement).
  * Fixed compatibility of ROOT trees written with HePMC3.0 and
    removed the typedefs in the dictionaries.
- Drop HepMC-type-mismatch-error.patch: incorporated upstream.
* Mon Jun  8 2020 Atri Bhattacharya <badshah400@gmail.com>
- Add HepMC-type-mismatch-error.patch: Fix type mismatch between
  function definition and function call flagged by GCC 10.
- Use autosetup to setup build dir and automatically apply patch.
* Wed Apr 22 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update Licensing:
  * Main License has been changed to GPL-3.0-or-later.
  * Python bindings licensed under the BSD-3-Clause.
- Package the appropriate License file for python-%%{name} package.
* Sat Apr  4 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.2.1:
  * Bugfix release.
  * Explicit usage of namespaces.
  * Disallow empty lines for the attribute names.
  * Added an option for explicit selection of packages for
    testing.
  * Adjustments in the interfaces of Tauola/Photos/mc-tester as a
    part of preparation to the new releases of these libraries
  * Experimental support for Python modulescompilation with pypy.
  * Bugfix in VectorString attribute.
  * Improvement in the attribute parsing.
  * Added an option to handle Python 3.9.
  * Implemented special treatment of some broken HePMC2 events.
- Update to version 3.2.0:
  * First release with Python bindings.
  * Added ReaderPlugin and WriterPlugin and macros to declare
    plugins.
  * Fixed GenCrossSection for the case of multiple
    cross-sections.
  * Removed Error class.
  * Removed ReaderHEPEVT::read_hepevt_particle(int i, bool
    iflong=true), ReaderHEPEVT::read_event(GenEvent &evt, bool
    iflong).
  * Removed ReaderHEPEVT::get_vertices_positions_present and
    ReaderHEPEVT::set_vertices_positions_present. The
    functionality above is implemented now Reader::set_options,
    Reader::get_options.
  * Fixed GenEvent::weight_names(). Now it should be called w/o
    arguments.
  * Added set_options, get_options to I/O classes for fine control
    of I/O.
  * The standard Selector members from Selector (e.g.
    Selector::MASS) were moved into a new class StandardSelector.
  * Added HEPMC3_ prefix to DEBUG, ERROR, WARNING  macros.
  * Added Reader::skip(int &) for fast forwarding of input.
  * Added to LHEF::Writer wrapper functions that can be used in
    Python.
  * use delete/override for class members.
- Build python3 bindings and package them in a new subpackage
  python3-HepMC; introduces BuildRequires on python3 and
  python3-devel.
- Build docs and examples by passing the appropriate options to
  cmake and package them in a -doc subpackage; drop commands used
  to build doc separately.
- Use %%bcond_with/%%bcond_without to enable pythia and disable
  rootio respectively.
- Add BuildRequires: pkgconfig(zlib) to enable linking against
  zlib.
- Package LICENCE and COPYING files using %%license.
* Sun Mar 29 2020 Atri Bhattacharya <badshah400@gmail.com>
- Disable setting rpaths on installed libs.
* Wed Jan  8 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.1.2:
  * Add GenParticle::abs_pid() to match FourVector::abs_eta(),
    abs_rap().
  * Add FourVector component-setting functions in HepMC method
    naming convention; deprecate old camelCase ones.
  * Bugfix release. Fixed some typos and minor bugs.
  * Fixed name of ROOT dictionary
  * Added more standard attributes
  * Extended documentation for doxygen
  * Added stremer output to Reader/Writer classes
  * Added procedures for boost, rotation and reflection to
    GenEvent
  * Added operators for printing events, particles, etc.
  * Added example with reading of compressed file and more tests
- Run fdupes on full docdir to link even more duplicated files.
* Wed May  1 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.1.1:
  * Improved treatment of events with cycles.
  * Improved documentation and examples.
- Changes from version 3.1.0:
  * Renaming the namespace, header directory and library name to
    HepMC3
  * SmartPointer is repaced with shared_ptr from C++11, so C++11
    is always required now
  * Split library into HepMC3(core) and HepMC3search (search
    engine)
  * New Search engine with highly abstract search capabilities
  * New readers and writers: WriterAsciiHepMC2, ReaderLHEF
  * Ascii files now have own string in header: Asciiv3
  * Deduction of input file format in ReaderFactory
  * Improved consistency of interface
  * Removal of most deprecated functions and  multiple bugfixes
  * Implemented test suite
  * Improved examples and documentation
- Drop sover.diff: so versioning added by upstream.
- Update Source url in keeping with upstream name changes.
- Adapt to name changes (HepMC -> HepMC3) in spec file wherever
  appropriate.
- Use %%%%cmake_build for building and parallel jobs when building
  documentation.
- Package new library libHepMC3search.
- New BuildRequires: graphviz-gd and ghostscript-fonts-std needed
  to generate docs, gcc-fortran needed for library.
* Wed Aug  9 2017 jengelh@inai.de
- Reapply shared library guidelines.
- Add sover.diff to force shlib versioning.
- Slightly trim description for length.
* Sat Aug  5 2017 badshah400@gmail.com
- Update to version 3.0.0:
  + See list of changes from:
    https://gitlab.cern.ch/hepmc/HepMC3/blob/3.0.0/ChangeLog.
- Drop shared library subpackage; there is no numbered shared lib
  any more. Package everything into the devel package.
- Use cmake macros for build and install.
- Drop unused cmake options.
- Build and install doxygen documentation.
- Manually install examples to docdir, running fdupes to weed out
  duplicated files.
- Update URL and Source URL for new upstream links.
- Updated file-list.
* Fri Dec  6 2013 badshah400@gmail.com
- Initial version
